function [im, nHistBin] = m_readFeatFile_2D(imFile, option)
% Load feature file created by BoW model code by Vedaldi 
% Inputs:
%   imFile: path to the feature file
%   option: if 'nHistBinOnly' then don't load the file and return nHistBin only
%       otherwise, this will load the file
% Outputs:
%   im: n*3 matrix for n keypoints
%       im(i,1), im(i,2), im(i,3): x, y, cluster index for i^th keypoint.
% By Minh Hoai Nguyen (minhhoai@cmu.edu)
% Date: 25 July 09

    
global CLUST_LEVEL
nHistBin = 10^CLUST_LEVEL; 

if exist('option', 'var') && strcmpi(option, 'nHistBinOnly')
    im = [];
    return;
end;

load(imFile, 'kpAssign');
n = size(kpAssign, 2); % number of keypoints.
im = zeros(n, 3);
im(:,1:2) = kpAssign([2,1],:)';
aux = kpAssign(2+CLUST_LEVEL,:)' - sum(10.^(1:CLUST_LEVEL-1));    
im(:,3) = aux;

